==> LL_utils-4.1.1.6-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/pull_down_tab_panel_variables.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)32 1.9 src/ll/config_editor/cgi-bin/pull_down_tab_panel_variables.pl, ll.config, ll_rrur2, rrur21042a 1/2/10 03:58:06\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

my ($mysql_host, $mysql_user, $mysql_pass, $mysql_db) = get_db_info(0);

my @editable_tables_by_clusterID = @{LLUtil::ALL_TABLES->{"tab_panel_variables"}->[0]};

my $query = $ENV{QUERY_STRING};
$query = unescape($query);

$_ = $query;
if(/id=(\d+)&name=(.*)/)
{
	my $json_str_0 = "Content-type: text/html\n\n";
	my $dbh = DBI->connect("DBI:mysql:database=$mysql_db;host=$mysql_host",$mysql_user,$mysql_pass);
	if(!defined($dbh))
	{
		my $json_str_err = $json_str_0."Error:".DBI->errstr;
		print $json_str_err;
		exit 1;
	}
	
	my $clusterID = $1;

	my $sql_str;
	my $sth;

	my $json_str = $json_str_0."[";

	foreach my $table (@editable_tables_by_clusterID)
	{
		$sql_str="select * from ".$table." where clusterID=".$clusterID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		$json_str .= "{type:'editable',table_name:'".$table."',key_id:'".$clusterID."',rows:[";
		while(my $ary_ref = $sth->fetchrow_arrayref)
		{
			$json_str .= "{columns:[";
			my $i;
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				$json_str .= "{col_name:\'".$sth->{NAME}->[$i]."\',col_value:'".$ary_ref->[$i]."',col_title:'".$sth->{NAME}->[$i]."'},";
			}
			$json_str =~ s/,$//g;
			$json_str .= "]},";
		}
		$json_str =~ s/,$//g;
		$json_str .= "]},";
	}	

	$json_str =~ s/,$//g;
	$json_str .= "]";
	print $json_str;
	if(defined($sth)) {$sth->finish();}
	$dbh->disconnect();

}

==> LL_utils-5.1.0.17-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/pull_down_tab_panel_variables.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)32 1.10 src/ll/config_editor/cgi-bin/pull_down_tab_panel_variables.pl, ll.config, ll_rrnep2, rrnep21206a 9/26/10 16:31:50\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

my ($db_host, $db_user, $db_pass, $db_db, $db_conn, $db2inst) = get_db_info(0);

my @editable_tables_by_clusterID = @{LLUtil::ALL_TABLES->{"tab_panel_variables"}->[0]};

my $query = $ENV{QUERY_STRING};
$query = unescape($query);

$_ = $query;
if(/id=(\d+)&name=(.*)/)
{
	my $json_str_0 = "Content-type: text/html\n\n";
	my $dbh = get_dbh(0);
	if(!defined($dbh))
	{
		error_and_exit($dbh->errstr);
	}
	
	my $clusterID = $1;

	my $sql_str;
	my $sth;

	my $json_str = $json_str_0."[";

	foreach my $table (@editable_tables_by_clusterID)
	{
		$sql_str="select * from ".$table." where clusterID=".$clusterID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		$json_str .= "{type:'editable',table_name:'".$table."',key_id:'".$clusterID."',rows:[";
		while(my $ary_ref = $sth->fetchrow_arrayref)
		{
			$json_str .= "{columns:[";
			my $i;
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				$json_str .= "{col_name:\'".$sth->{NAME}->[$i]."\',col_value:'".$ary_ref->[$i]."',col_title:'".$sth->{NAME}->[$i]."'},";
			}
			$json_str =~ s/,$//g;
			$json_str .= "]},";
		}
		$json_str =~ s/,$//g;
		$json_str .= "]},";
	}	

	$json_str =~ s/,$//g;
	$json_str .= "]";
	print $json_str;
	if(defined($sth)) {$sth->finish();}
	$dbh->disconnect();

}
